@@ -181,7 +181,7 @@ void LoaderWidget::init()
 
 void LoaderWidget::setCurrentURL( KURL url )
 {
-  searchedDirectory->setText( url.prettyURL(1,KURL::StripFileProtocol) );
+  searchedDirectory->setText( vfs::pathOrURL( url, 1) );
 }
 
 void LoaderWidget::setValues( int fileNum, int dirNum, KIO::filesize_t total )
@@ -198,7 +198,7 @@ void LoaderWidget::slotCancelled()
 
 DiskUsage::DiskUsage( QString confGroup, QWidget *parent, char *name ) : QWidgetStack( parent, name ),
                       currentDirectory( 0 ), root( 0 ), configGroup( confGroup ), loading( false ),
-                      abortLoading( false ), clearAfterAbort( false ), searchVfs( 0 )
+                      abortLoading( false ), clearAfterAbort( false ), deleting( false ), searchVfs( 0 )
 {
   listView = new DUListView( this, "DU ListView" );
   lineView = new DULines( this, "DU LineView" );
@@ -247,7 +247,7 @@ void DiskUsage::load( KURL baseDir )
   baseURL = baseDir;
   baseURL.setPath( baseDir.path( -1 ) );
 
-  root = new Directory( baseURL.fileName().local8Bit(), baseDir.prettyURL( 0, KURL::StripFileProtocol ) );
+  root = new Directory( baseURL.fileName(), vfs::pathOrURL( baseDir ) );
 
   directoryStack.clear();
   parentStack.clear();
@@ -269,7 +269,6 @@ void DiskUsage::load( KURL baseDir )
   }
 
   searchVfs->vfs_setQuiet( true );
-  searchVfs->vfs_enableRefresh( false );
   currentVfile = 0;
 
   if( !loading )
@@ -412,7 +411,7 @@ void DiskUsage::dirUp()
       if( KMessageBox::questionYesNo( this, i18n( "Stepping into the parent directory requires "
                                                   "loading the content of the \"%1\" URL. Do you wish "
                                                   "to continue?" )
-                                            .arg( up.prettyURL( 0, KURL::StripFileProtocol ) ),
+                                            .arg( vfs::pathOrURL( up ) ),
                                             i18n( "Krusader::DiskUsage" ), KStdGuiItem::yes(),
                                             KStdGuiItem::no(), "DiskUsageLoadParentDir"
                                             ) == KMessageBox::Yes )
@@ -452,7 +451,7 @@ File * DiskUsage::getFile( QString path )
     return 0;
 
   for( Iterator<File> it = dirEntry->iterator(); it != dirEntry->end(); ++it )
-    if( (*it)->fileName() == file )
+    if( (*it)->name() == file )
       return *it;
 
   return 0;
@@ -469,8 +468,10 @@ void DiskUsage::clear()
   root = currentDirectory = 0;
 }
 
-void DiskUsage::calculateSizes( Directory *dirEntry, bool emitSig )
+int DiskUsage::calculateSizes( Directory *dirEntry, bool emitSig, int depth )
 {
+  int changeNr = 0;
+
   if( dirEntry == 0 )
     dirEntry = root;
 
@@ -483,7 +484,7 @@ void DiskUsage::calculateSizes( Directory *dirEntry, bool emitSig )
     if( !item->isExcluded() )
     {
       if( item->isDir() )
-        calculateSizes( dynamic_cast<Directory *>( item ), emitSig );
+        changeNr += calculateSizes( dynamic_cast<Directory *>( item ), emitSig, depth + 1 );
       else
         own += item->size();
 
@@ -497,22 +498,31 @@ void DiskUsage::calculateSizes( Directory *dirEntry, bool emitSig )
   if( dirEntry == currentDirectory )
     currentSize = total;
 
-  if( emitSig && ( own != oldOwn || total != oldTotal ) )
+  if( emitSig && ( own != oldOwn || total != oldTotal ) ) {
     emit changed( dirEntry );
+    changeNr++;
+  }
+
+  if( depth == 0 && changeNr != 0 )
+    emit changeFinished();
+  return changeNr;
 }
 
-void DiskUsage::exclude( File *file, bool calcPercents )
+int DiskUsage::exclude( File *file, bool calcPercents, int depth )
 {
+  int changeNr = 0;
+
   if( !file->isExcluded() )
   {
     file->exclude( true );
     emit changed( file );
+    changeNr++;
 
     if( file->isDir() )
     {
       Directory *dir = dynamic_cast<Directory *>( file );
       for( Iterator<File> it = dir->iterator(); it != dir->end(); ++it )
-        exclude( *it, false );
+        changeNr += exclude( *it, false, depth + 1 );
     }
   }
 
@@ -522,26 +532,39 @@ void DiskUsage::exclude( File *file, bool calcPercents )
     calculatePercents( true );
     createStatus();
   }
+
+  if( depth == 0 && changeNr != 0 )
+    emit changeFinished();
+
+  return changeNr;
 }
 
-void DiskUsage::include( Directory *dir )
+int DiskUsage::include( Directory *dir, int depth )
 {
+  int changeNr = 0;
+
   if( dir == 0 )
-    return;
+    return 0;
 
   for( Iterator<File> it = dir->iterator(); it != dir->end(); ++it )
   {
     File *item = *it;
 
     if( item->isDir() )
-      include( dynamic_cast<Directory *>( item ) );
+      changeNr += include( dynamic_cast<Directory *>( item ), depth + 1 );
 
     if( item->isExcluded() )
     {
       item->exclude( false );
       emit changed( item );
+      changeNr++;
     }
   }
+
+  if( depth == 0 && changeNr != 0 )
+    emit changeFinished();
+
+  return changeNr;
 }
 
 void DiskUsage::includeAll()
@@ -552,10 +575,12 @@ void DiskUsage::includeAll()
   createStatus();
 }
 
-void DiskUsage::del( File *file, bool calcPercents )
+int DiskUsage::del( File *file, bool calcPercents, int depth )
 {
+  int deleteNr = 0;
+
   if( file == root )
-    return;
+    return 0;
 
   krConfig->setGroup( "General" );
   bool trash = krConfig->readBoolEntry( "Move To Trash", _MoveToTrash );
@@ -567,11 +592,11 @@ void DiskUsage::del( File *file, bool calcPercents )
     krConfig->setGroup( "Advanced" );
     if ( krConfig->readBoolEntry( "Confirm Delete", _ConfirmDelete ) ) {
       QString s, b;
-        if ( trash && url.isLocalFile() ) {
-          s = i18n( "trash" );
-          b = i18n( "&Trash" );
+      if ( trash && url.isLocalFile() ) {
+        s = i18n( "Do you really want to move this item to the trash?" );
+        b = i18n( "&Trash" );
       } else {
-        s = i18n( "delete" ) + s;
+        s = i18n( "Do you really want to delete this item?" );
         b = i18n( "&Delete" );
       }
 
@@ -579,10 +604,11 @@ void DiskUsage::del( File *file, bool calcPercents )
       name.append( file->fullPath() );
       // show message
       // note: i'm using continue and not yes/no because the yes/no has cancel as default button
-      if ( KMessageBox::warningContinueCancelList( krApp, i18n( "Are you sure you want to " ) + s
-                                                 , name, i18n( "Warning" ), b ) != KMessageBox::Continue )
-        return ;
+      if ( KMessageBox::warningContinueCancelList( krApp, s, name, i18n( "Warning" ), b ) != KMessageBox::Continue )
+        return 0;
     }
+
+    emit status( i18n( "Deleting %1..." ).arg( file->name() ) );
   }
 
   if( file == currentDirectory )
@@ -594,7 +620,7 @@ void DiskUsage::del( File *file, bool calcPercents )
 
     Iterator<File> it;
     while( ( it = dir->iterator() ) != dir->end() )
-      del( *it, false );
+      deleteNr += del( *it, false, depth + 1 );
 
     QString path;
     for( const Directory *d = (Directory*)file; d != root && d && d->parent() != 0; d = d->parent() )
@@ -602,13 +628,14 @@ void DiskUsage::del( File *file, bool calcPercents )
       if( !path.isEmpty() )
         path = "/" + path;
 
-      path = d->fileName() + path;
+      path = d->name() + path;
     }
 
     contentMap.remove( path );
   }
 
   emit deleted( file );
+  deleteNr++;
 
   QGuardedPtr<KIO::Job> job;
 
@@ -626,12 +653,23 @@ void DiskUsage::del( File *file, bool calcPercents )
     job = new KIO::DeleteJob( vfs::fromPathOrURL( file->fullPath() ), false, false);
   }
 
+  deleting = true;    // during qApp->processEvent strange things can occur
+  grabMouse();        // that's why we disable the mouse and keyboard events
+  grabKeyboard();
+
   while( !job.isNull() )
     qApp->processEvents();
 
+  releaseMouse();
+  releaseKeyboard(); 
+  deleting = false;
+
   ((Directory *)(file->parent()))->remove( file );
   delete file;
 
+  if( depth == 0 )
+    createStatus();
+
   if( calcPercents )
   {
     calculateSizes( root, true );
@@ -639,6 +677,11 @@ void DiskUsage::del( File *file, bool calcPercents )
     createStatus();
     emit enteringDirectory( currentDirectory );
   }
+
+  if( depth == 0 && deleteNr != 0 )
+    emit deleteFinished();
+
+  return deleteNr;
 }
 
 void * DiskUsage::getProperty( File *item, QString key )
@@ -682,7 +725,7 @@ void DiskUsage::createStatus()
       url.addPath( dirEntry->directory() );
 
   emit status( i18n( "Current directory:%1,  Total size:%2,  Own size:%3" )
-               .arg( url.prettyURL(-1,KURL::StripFileProtocol) )
+               .arg( vfs::pathOrURL( url, -1 ) )
                .arg( " "+KRpermHandler::parseSize( dirEntry->size() ) )
                .arg( " "+KRpermHandler::parseSize( dirEntry->ownSize() ) ) );
 }
@@ -934,8 +977,10 @@ QPixmap DiskUsage::getIcon( QString mime )
   return icon;
 }
 
-void DiskUsage::calculatePercents( bool emitSig, Directory *dirEntry )
+int DiskUsage::calculatePercents( bool emitSig, Directory *dirEntry, int depth )
 {
+  int changeNr = 0;
+
   if( dirEntry == 0 )
     dirEntry = root;
 
@@ -957,13 +1002,19 @@ void DiskUsage::calculatePercents( bool emitSig, Directory *dirEntry )
       int oldPerc = item->intPercent();
       item->setPercent( newPerc );
 
-      if( emitSig && newPerc != oldPerc )
+      if( emitSig && newPerc != oldPerc ) {
         emit changed( item );
+        changeNr++;
+      }
 
       if( item->isDir() )
-        calculatePercents( emitSig, dynamic_cast<Directory *>( item ) );
+        changeNr += calculatePercents( emitSig, dynamic_cast<Directory *>( item ), depth + 1 );
     }
   }
+
+  if( depth == 0 && changeNr != 0 )
+    emit changeFinished();
+  return changeNr;
 }
 
 QString DiskUsage::getToolTip( File *item )
@@ -976,7 +1027,7 @@ QString DiskUsage::getToolTip( File *item )
   QDateTime tmp(QDate(t->tm_year+1900, t->tm_mon+1, t->tm_mday), QTime(t->tm_hour, t->tm_min));
   QString date = KGlobal::locale()->formatDateTime(tmp);
 
-  QString str = "<qt><h5><table><tr><td>" + i18n( "Name:" ) +  "</td><td>" + item->fileName() + "</td></tr>"+
+  QString str = "<qt><h5><table><tr><td>" + i18n( "Name:" ) +  "</td><td>" + item->name() + "</td></tr>"+
                 "<tr><td>" + i18n( "Type:" ) +  "</td><td>" + mime + "</td></tr>"+
                 "<tr><td>" + i18n( "Size:" ) +  "</td><td>" + KRpermHandler::parseSize( item->size() ) + "</td></tr>";
 
@@ -1035,6 +1086,20 @@ File * DiskUsage::getCurrentFile()
 
 bool DiskUsage::event( QEvent * e )
 {
+  if( deleting ) {                       // if we are deleting, disable the mouse and
+    switch( e->type() ) {                // keyboard events
+    case QEvent::MouseButtonPress:
+    case QEvent::MouseButtonRelease:
+    case QEvent::MouseButtonDblClick:
+    case QEvent::MouseMove:
+    case QEvent::KeyPress:
+    case QEvent::KeyRelease:
+      return true;
+    default:
+      break;
+    }
+  }
+
   if ( e->type() == QEvent::AccelOverride )
   {
     QKeyEvent* ke = (QKeyEvent*) e;
