@@ -146,14 +146,11 @@ void KrDetailedViewItem::repaintItem() {
       setText(id, _vf->vfile_getGroup());
     }
     // if we've got an extention column, clip the name accordingly
-    QString name = _vf->vfile_getName(), ext = "";
+    QString name = this->name(), ext = "";
     if ((id = COLUMN(Extention)) != -1 && !_vf->vfile_isDir()) {
-      int i;
-      if ((i = name.findRev('.')) > 0) {
-        ext = name.mid(i+1);
-        name = name.mid(0, i);
-      }
-      setText(id, ext);
+    	ext = this->extension();
+	name = this->name(false); // request name without extension
+      	setText(id, ext);
     }
     setText(COLUMN(Name), name);
 #ifndef FASTER
@@ -203,89 +200,25 @@ void KrDetailedViewItem::paintCell(QPainter *p, const QColorGroup &cg, int colum
 
   // end of uglyness
 
-  
-  // begin of custom color calculation
-  krConfig->setGroup("Colors");
-  
-  // if KDE deafault: do not touch color group!
-  if (!KrColorCache::getColorCache().isKDEDefault())
+  KrColorItemType colorItemType;
+  colorItemType.m_activePanel = (dynamic_cast<KrView *>(listView()) == ACTIVE_PANEL->view);
+  colorItemType.m_alternateBackgroundColor = isAlternate();
+  colorItemType.m_currentItem = (listView()->currentItem() == this);
+  colorItemType.m_selectedItem = isSelected();
+  if (VF->vfile_isSymLink())
   {
-    bool markCurrentAlways = KrColorCache::getColorCache().isShowCurrentItemAlways();
-    bool isActive = (dynamic_cast<KrView *>(listView()) == ACTIVE_PANEL->view);
-    bool isCurrent = listView()->currentItem() == this;
-    
-    // First calculate fore- and background.
-    QColor background = isAlternate()?KrColorCache::getColorCache().getAlternateBackgroundColor(isActive):KrColorCache::getColorCache().getBackgroundColor(isActive);
-    QColor foreground;
-    if (VF->vfile_isSymLink())
-    {
-       if (_vf->vfile_getMime() == "Broken Link !" )
-          foreground = KrColorCache::getColorCache().getInvalidSymlinkForegroundColor(isActive);
-       else
-          foreground = KrColorCache::getColorCache().getSymlinkForegroundColor(isActive);
-    }
-    else if (VF->vfile_isDir())
-       foreground = KrColorCache::getColorCache().getDirectoryForegroundColor(isActive);
-    else if (VF->vfile_isExecutable())
-       foreground = KrColorCache::getColorCache().getExecutableForegroundColor(isActive);
-    else
-       foreground = KrColorCache::getColorCache().getForegroundColor(isActive);
-       
-    // set the background color
-    _cg.setColor(QColorGroup::Base, background);
-    _cg.setColor(QColorGroup::Background, background);
-      
-    // set the foreground color
-    _cg.setColor(QColorGroup::Text, foreground);
-
-    // now the color of a marked item
-    QColor markedBackground = isAlternate()?KrColorCache::getColorCache().getAlternateMarkedBackgroundColor(isActive):KrColorCache::getColorCache().getMarkedBackgroundColor(isActive);
-    QColor markedForeground = KrColorCache::getColorCache().getMarkedForegroundColor(isActive);
-    if (!markedForeground.isValid()) // transparent
-       // choose fore- or background, depending on its contrast compared to markedBackground
-       markedForeground = setColorIfContrastIsSufficient(markedBackground, foreground, background);
-
-      // set it in the color group (different group color than normal foreground!)
-    _cg.setColor(QColorGroup::HighlightedText, markedForeground);
-    _cg.setColor(QColorGroup::Highlight, markedBackground);
-
-    // In case the current item is a selected one, set the fore- and background colors for the contrast calculation below
-    if (isSelected())
-    {
-        background = markedBackground;
-        foreground = markedForeground;
-    }
-
-    // finally the current item
-    if (isCurrent && (markCurrentAlways || isActive))
-    // if this is the current item AND the panels has tho focus OR the current should be marked always
-    {
-       QColor currentBackground = KrColorCache::getColorCache().getCurrentBackgroundColor(isActive);
-       if (!currentBackground.isValid()) // transparent
-          currentBackground = background;
-       
-       // set the background
-       _cg.setColor(QColorGroup::Highlight, currentBackground);
-       _cg.setColor(QColorGroup::Base, currentBackground);
-       _cg.setColor(QColorGroup::Background, currentBackground);
-
-       QColor color;
-       if (isSelected()) 
-          color = KrColorCache::getColorCache().getCurrentMarkedForegroundColor(isActive);
-       if (!color.isValid()) // not used
-       {
-          color = KrColorCache::getColorCache().getCurrentForegroundColor(isActive);
-          if (!color.isValid()) // transparent
-            // choose fore- or background, depending on its contrast compared to markedBackground
-            color = setColorIfContrastIsSufficient(currentBackground, foreground, background);
-       }
-       
-       // set the foreground
-       _cg.setColor(QColorGroup::Text, color);
-       _cg.setColor(QColorGroup::HighlightedText, color);
-    }
+     if (_vf->vfile_getMime() == "Broken Link !" )
+        colorItemType.m_fileType = KrColorItemType::InvalidSymlink;
+     else
+        colorItemType.m_fileType = KrColorItemType::Symlink;
   }
-
+  else if (VF->vfile_isDir())
+     colorItemType.m_fileType = KrColorItemType::Directory;
+  else if (VF->vfile_isExecutable())
+     colorItemType.m_fileType = KrColorItemType::Executable;
+  else
+     colorItemType.m_fileType = KrColorItemType::File;
+  KrColorCache::getColorCache().getColors(_cg, colorItemType);
 	// center the <DIR> thing if needed
 	if(column != COLUMN(Size))
 		QListViewItem::paintCell(p, _cg, column, width, align);
@@ -313,42 +246,55 @@ const QColor & KrDetailedViewItem::setColorIfContrastIsSufficient(const QColor &
 
 int KrDetailedViewItem::compare(QListViewItem *i,int col,bool ascending ) const {
   bool ignoreCase = (PROPS->sortMode & KrViewProperties::IgnoreCase);
+	bool alwaysSortDirsByName = (PROPS->sortMode & KrViewProperties::AlwaysSortDirsByName);
   int asc = ( ascending ? -1 : 1 );
-  KrViewItem *other = dynamic_cast<KrViewItem*>(i);
+  KrDetailedViewItem *other = (KrDetailedViewItem *)(i);
+
+  bool thisDir = VF->vfile_isDir();
+  bool otherDir = other->VF->vfile_isDir();
 
   // handle directory sorting
-  if (VF->vfile_isDir()){
-    if (!other->VF->vfile_isDir()) return 1*asc;
-  } else if(other->VF->vfile_isDir()) return -1*asc;
+  if ( thisDir ){
+    if ( !otherDir ) return 1*asc;
+  } else if( otherDir ) return -1*asc;
 
-  QString text0 = name();
-  if (text0 == "..") return 1*asc;
-  
-  QString itext0 = other->name();
-  if (itext0 == "..") return -1*asc;
-
-  if( ignoreCase )
-  {
-    text0  = text0.lower();
-    itext0 = itext0.lower();
-  }
-
-  if (col == COLUMN(Name) ) {
+  if ( isDummy() ) return 1*asc;
+  if ( other->isDummy() ) return -1*asc;
+		
+  if (col == COLUMN(Name) ||
+			(alwaysSortDirsByName && thisDir && otherDir )) {
       // localeAwareCompare doesn't handle names that start with a dot
-		if (text0.startsWith(".")) {
-			if (!itext0.startsWith(".")) return 1*asc;
-		} else if (itext0.startsWith(".")) return -1*asc;
+		QString text0 = name();
+		QString itext0 = other->name();
+
+		if( ignoreCase )
+		{
+			text0  = text0.lower();
+			itext0 = itext0.lower();
+		}
+
+		if ( isHidden() ) {
+			if ( !other->isHidden() ) return 1*asc;
+		} else if ( other->isHidden() ) return -1*asc;
 		if (!ignoreCase && !PROPS->localeAwareCompareIsCaseSensitive) {
 			// sometimes, localeAwareCompare is not case sensative. in that case,
 			// we need to fallback to a simple string compare (KDE bug #40131)
 			return QString::compare(text0, itext0);
 		} else return QString::localeAwareCompare(text0,itext0);
   } else if (col == COLUMN(Size) ) {
-      return QString::compare(num2qstring(VF->vfile_getSize()),num2qstring(other->VF->vfile_getSize()));
+      if( VF->vfile_getSize() == other->VF->vfile_getSize() )
+        return 0;
+      return (VF->vfile_getSize() > other->VF->vfile_getSize() ? 1 : -1);
   } else if (col == COLUMN(DateTime) ) {
+      if( VF->vfile_getTime_t() == other->VF->vfile_getTime_t() )
+        return 0;
       return (VF->vfile_getTime_t() > other->VF->vfile_getTime_t() ? 1 : -1);
   } else if (col == COLUMN(Permissions) && PROPS->numericPermissions) {
-		return ((text(col).toLong() > i->text(col).toLong()) ? 1 : -1);
+		int thisPerm = VF->vfile_getMode() & PERM_BITMASK;
+		int otherPerm = other->VF->vfile_getMode() & PERM_BITMASK;
+		if( thisPerm == otherPerm )
+			return 0;
+		return ((thisPerm > otherPerm) ? 1 : -1);
   } else {
       QString e1 = (!ignoreCase ? text(col) : text(col).lower());
       QString e2 = (!ignoreCase ? i->text(col) : i->text(col).lower());
