@@ -42,27 +42,35 @@ class KrViewItem {
 	friend class KrView;
 
 public:
-   virtual inline QString name() const { return _vf->vfile_getName(); }
-   virtual QString dateTime() const;
-   virtual QString description() const;
-   virtual bool isSelected() const = 0;
-   virtual void setSelected( bool s ) = 0;
-   virtual QPixmap icon();
-   
-	KrViewItem(vfile *vf, const KrViewProperties* properties): _vf(vf), dummyVfile(false), _viewProperties(properties) {}
-   virtual ~KrViewItem() { if (dummyVfile) delete _vf; }
+	virtual const QString& name(bool withExtension=true) const;
+	virtual inline bool hasExtension() const { return _hasExtension; }
+	virtual inline const QString& extension() const { return _extension; }
+	virtual QString dateTime() const;
+	virtual QString description() const;
+	virtual bool isSelected() const = 0;
+	virtual void setSelected( bool s ) = 0;
+	virtual QPixmap icon();
+	
+	KrViewItem(vfile *vf, const KrViewProperties* properties);
+	virtual ~KrViewItem() { if (dummyVfile) delete _vf; }
 		
-   // DON'T USE THOSE OUTSIDE THE VIEWS!!!
-   virtual inline const vfile* getVfile() const { return _vf; }
-   virtual inline vfile* getMutableVfile() { return _vf; }
+	// DON'T USE THOSE OUTSIDE THE VIEWS!!!
+	inline const vfile* getVfile() const { return _vf; }
+	inline vfile* getMutableVfile() { return _vf; }
+	inline bool isDummy() const { return dummyVfile; }
+	inline bool isHidden() const { return _hidden; }
 
 protected:
 	// used INTERNALLY when calculation of dir size changes the displayed size of the item
 	inline void setSize(KIO::filesize_t size) { _vf->vfile_setSize(size); }
-
+	
 	vfile* _vf;			// each view item holds a pointer to a corrosponding vfile for fast access	
 	bool dummyVfile;	// used in case our item represents the ".." (updir) item
 	const KrViewProperties* _viewProperties;
+	bool _hasExtension;
+	bool _hidden;
+	QString _name;
+	QString _extension;
 };
 
 #endif
