@@ -50,10 +50,16 @@
 
 #include <kmimetype.h>
 
+#define  EVENT_PROCESS_DELAY     250
+
 KRSearchMod::KRSearchMod( const KRQuery* q )
 {
   stopSearch = false; /// ===> added
   query = new KRQuery( *q );
+  connect( query, SIGNAL( status( const QString & ) ), 
+           this,  SIGNAL( searching(const QString&) ) );
+  connect( query, SIGNAL( processEvents( bool & ) ), 
+           this,  SLOT  ( slotProcessEvents( bool & ) ) );
 
   remote_vfs = 0;
   virtual_vfs = 0;
@@ -72,7 +78,8 @@ void KRSearchMod::start()
 {
   unScannedUrls.clear();
   scannedUrls.clear();
-
+  timer.start();
+  
   KURL::List whereToSearch = query->searchInDirs();
 
   // search every dir that needs to be searched
@@ -98,29 +105,26 @@ void KRSearchMod::scanURL( KURL url )
 
     if( stopSearch ) return;
 
-    if( query->isExcluded( urlToCheck ) )
-      continue;
+    if( query->isExcluded( urlToCheck ) ) {
+      if( !query->searchInDirs().contains( urlToCheck ) )
+        continue;
+    }
 
     if( scannedUrls.contains( urlToCheck ) )
       continue;
     scannedUrls.push( urlToCheck );
 
-    emit searching( urlToCheck.prettyURL(0,KURL::StripFileProtocol) );
+    emit searching( vfs::pathOrURL( urlToCheck ) );
 
     if ( urlToCheck.isLocalFile() )
       scanLocalDir( urlToCheck );
     else
       scanRemoteDir( urlToCheck );
-
-    qApp->processEvents(); // do a last one, in case passes%50 != 0
   }
 }
 
 void KRSearchMod::scanLocalDir( KURL urlToScan )
 {
-  int passes = 0;
-  const int NO_OF_PASSES = 50;
-
   QString dir = urlToScan.path( 1 );
 
   DIR* d = opendir( dir.local8Bit() );
@@ -165,13 +169,17 @@ void KRSearchMod::scanLocalDir( KURL urlToScan )
       if ( KRarcHandler::arcSupported( type ) )
       {
         KURL archiveURL = url;
+        bool encrypted;
+        QString realType = KRarcHandler::getType( encrypted, url.path(), mime );
 
-        if ( type == "-tbz" || type == "-tgz" || type == "tarz" || type == "-tar" )
-          archiveURL.setProtocol( "tar" );
-        else
-          archiveURL.setProtocol( "krarc" );
+        if( !encrypted ) {
+          if ( realType == "-tbz" || realType == "-tgz" || realType == "tarz" || realType == "-tar" )
+            archiveURL.setProtocol( "tar" );
+          else
+            archiveURL.setProtocol( "krarc" );
 
-        unScannedUrls.push( archiveURL );
+          unScannedUrls.push( archiveURL );
+        }
       }
     }
 
@@ -180,9 +188,14 @@ void KRSearchMod::scanLocalDir( KURL urlToScan )
       // if we got here - we got a winner
       results.append( dir + name );
       emit found( name, dir, ( KIO::filesize_t ) stat_p.st_size, stat_p.st_mtime, KRpermHandler::mode2QString( stat_p.st_mode ), query->foundText() );
-      if ( passes++ % NO_OF_PASSES == 0 ) qApp->processEvents();
     }
     delete vf;
+
+    if( timer.elapsed() >= EVENT_PROCESS_DELAY ) {
+      qApp->processEvents();
+      timer.start();
+      if( stopSearch ) return;    
+    }
   }
   // clean up
   closedir( d );
@@ -190,9 +203,6 @@ void KRSearchMod::scanLocalDir( KURL urlToScan )
 
 void KRSearchMod::scanRemoteDir( KURL url )
 {
-  int passes = 0;
-  const int NO_OF_PASSES = 50;
-  
   vfs * vfs_;
   
 
@@ -222,12 +232,22 @@ void KRSearchMod::scanRemoteDir( KURL url )
     if( query->match( vf ) )
     {
       // if we got here - we got a winner
-      results.append( fileURL.prettyURL( -1, KURL::StripFileProtocol ) );
+      results.append( vfs::pathOrURL( fileURL, -1 ) );
       
-      emit found( fileURL.fileName(), fileURL.upURL().prettyURL( -1, KURL::StripFileProtocol ), vf->vfile_getSize(), vf->vfile_getTime_t(), vf->vfile_getPerm(), query->foundText() );
-      if ( passes++ % NO_OF_PASSES == 0 ) qApp->processEvents();
+      emit found( fileURL.fileName(), vfs::pathOrURL( fileURL.upURL(), -1 ), vf->vfile_getSize(), vf->vfile_getTime_t(), vf->vfile_getPerm(), query->foundText() );
+    }
+
+    if( timer.elapsed() >= EVENT_PROCESS_DELAY ) {
+      qApp->processEvents();
+      timer.start();
+      if( stopSearch ) return;    
     }
   }
 }
 
+void KRSearchMod::slotProcessEvents( bool & stopped ) {
+  qApp->processEvents();
+  stopped = stopSearch;
+}
+
 #include "krsearchmod.moc"
