@@ -31,24 +31,40 @@
 #define KRQUERY_H
 
 #include <qstringlist.h>
+#include <qdatetime.h>
 #include <time.h>
 #include <kurl.h>
+#include <kio/jobclasses.h>
 #include "vfile.h"
 
-class KRQuery {
+class KFileItem;
+
+class KRQuery : public QObject {
+  Q_OBJECT
+
 public:
   // null query
   KRQuery();
   // query only with name filter
-  KRQuery( QString name, bool matchCase = true );
+  KRQuery( const QString &name, bool matchCase = true );
+  // copy constructor
+  KRQuery( const KRQuery & );
+  // let operator
+  KRQuery& operator=(const KRQuery &);
+  // destructor
+  virtual ~KRQuery();
 
   // matching a file with the query
   bool match( vfile *file ) const;// checks if the given vfile object matches the conditions
+  // matching a KIO file with the query
+  bool match( KFileItem *file ) const;// checks if the given vfile object matches the conditions
   // matching a name with the query
-  bool match( QString name ) const;// matching the filename only
+  bool match( const QString &name ) const;// matching the filename only
+  // matching the name of the directory
+  bool matchDirName( const QString &name ) const;
 
   // sets the text for name filtering
-  void setNameFilter( QString text, bool cs=true );
+  void setNameFilter( const QString &text, bool cs=true );
   // returns the current filter mask
   const QString& nameFilter() const { return origFilter; }
   // returns whether the filter is case sensitive
@@ -58,7 +74,7 @@ public:
   bool isNull() {return bNull;};
 
   // sets the content part of the query
-  void setContent( QString content, bool cs=true, bool wholeWord=false );
+  void setContent( const QString &content, bool cs=true, bool wholeWord=false, bool remoteSearch=false );
 
   // sets the minimum file size limit
   void setMinimumFileSize( KIO::filesize_t );
@@ -71,11 +87,11 @@ public:
   void setOlderThan( time_t time );
 
   // sets the owner
-  void setOwner( QString ownerIn );
+  void setOwner( const QString &ownerIn );
   // sets the group
-  void setGroup( QString groupIn );
+  void setGroup( const QString &groupIn );
   // sets the permissions
-  void setPermissions( QString permIn );
+  void setPermissions( const QString &permIn );
 
   // sets the mimetype for the query
   // type, must be one of the following:
@@ -84,7 +100,7 @@ public:
   //            i18n("Text Files"), i18n("Video Files"), i18n("Audio Files")
   // 3. i18n("Custom") in which case you must supply a list of valid mime-types
   //    in the member QStringList customType
-  void setMimeType( QString typeIn, QStringList customList = QStringList() );
+  void setMimeType( const QString &typeIn, QStringList customList = QStringList() );
   // true if setMimeType was called
   bool hasMimeType()  { return type.isEmpty(); }
 
@@ -102,21 +118,31 @@ public:
   bool followLinks() { return followLinksP; }
 
   // sets the folders where the searcher will search
-  void setSearchInDirs( KURL::List urls );
+  void setSearchInDirs( const KURL::List &urls );
   // gets the folders where the searcher searches
-  KURL::List searchInDirs() { return whereToSearch; }
+  const KURL::List & searchInDirs() { return whereToSearch; }
   // sets the folders where search is not permitted
-  void setDontSearchInDirs( KURL::List urls );
+  void setDontSearchInDirs( const KURL::List &urls );
   // gets the folders where search is not permitted
-  KURL::List dontSearchInDirs() { return whereNotToSearch; }
+  const KURL::List & dontSearchInDirs() { return whereNotToSearch; }
   // checks if a URL is excluded
-  bool isExcluded( KURL url );
-
+  bool isExcluded( const KURL &url );
+  // gives whether we search for content
+  bool isContentSearched() const { return !contain.isEmpty(); }
+  
   const QString& foundText() const { return lastSuccessfulGrep; }
 
+protected:
+  // important to know whether the event processor is connected
+  virtual void connectNotify ( const char * signal );
+  // important to know whether the event processor is connected
+  virtual void disconnectNotify ( const char * signal );
+
 protected:
   QStringList matches;           // what to search
   QStringList excludes;          // what to exclude
+  QStringList includedDirs;      // what dirs to include
+  QStringList excludedDirs;      // what dirs to exclude
   bool matchesCaseSensitive;
 
   bool bNull;                    // flag if the query is null
@@ -124,6 +150,7 @@ protected:
   QString contain;               // file must contain this string
   bool containCaseSensetive;
   bool containWholeWord;
+  bool containOnRemote;
 
   KIO::filesize_t minSize;
   KIO::filesize_t maxSize;
@@ -145,13 +172,37 @@ protected:
   KURL::List whereToSearch;     // directorys to search
   KURL::List whereNotToSearch;  // directorys NOT to search
 
+signals:
+  void status( const QString &name );
+  void processEvents( bool & stopped );
+
 private:
+  bool matchCommon( const QString &, const QStringList &, const QStringList & ) const;
   bool checkPerm(QString perm) const;
   bool checkType(QString mime) const;
   bool containsContent( QString file ) const;
+  bool containsContent( KURL url ) const;
+  bool checkBuffer( const char *buffer, int len ) const;
+  bool checkLines( const char *buffer, int len ) const;
+  bool checkTimer() const;
+  QStringList split( QString );
 
-  QString origFilter;
-  mutable QString lastSuccessfulGrep;
+private slots:
+  void containsContentData(KIO::Job *, const QByteArray &);
+  void containsContentFinished(KIO::Job*);
+
+private:
+  QString                  origFilter;
+  mutable bool             busy;
+  mutable bool             containsContentResult;
+  mutable char *           receivedBuffer;
+  mutable int              receivedBufferLen;
+  mutable QString          lastSuccessfulGrep;
+  mutable QString          fileName;
+  mutable KIO::filesize_t  receivedBytes;
+  mutable KIO::filesize_t  totalBytes;
+  mutable int              processEventsConnected;
+  mutable QTime            timer;
 };
 
 #endif
