@@ -46,8 +46,8 @@
 #define _ShowTerminalEmulator false 
 // Remember Position
 #define _RememberPos      true 
-// Panels Save Settings
-#define _PanelsSave       "Tabs"
+// Start to tray
+#define _StartToTray      false
 // Left Tab Bar
 // Right Tab Bar
 // Left Panel Popup
@@ -103,6 +103,8 @@
 #define _AlternateBackground  true
 // Show current item even if not focussed
 #define _ShowCurrentItemAlways false
+// Dim the colors of the inactive panel
+#define _DimInactiveColors     false
 // Human Readable Size
 #define _HumanReadableSize		true
 // With Icons
@@ -111,8 +113,14 @@
 #define _SingleClickSelects false
 // Numeric Permissions
 #define _NumericPermissions false
+// Number of Columns in the Brief View
+#define _NumberOfBriefColumns  3
+// Create brief mode panels
+#define _DefaultPanelType   "Detailed"
 // Show splashscreen
 #define _ShowSplashScreen true
+// Single instance mode
+#define _SingleInstanceMode false
 
 /////////////////////// [General]
 // Mimetype Magic /////
@@ -140,7 +148,7 @@
 // AutoMount //////////
 #define _AutoMount        false 
 // Preserving date //////////
-#define _PreserveDate     false
+#define _PreserveAttributes false
 // Nonmount Points ////
 #define _NonMountPoints	"/, "
 // Confirm Unempty Dir //     (for delete)
@@ -181,6 +189,8 @@
 #define _DoDEB         true
 // Do Lha /////////////
 #define _DoLha         true 
+// Do 7z /////////////          ====> new
+#define _Do7z          true
 // Allow Move Into Archive //
 #define _MoveIntoArchive false 
 // Test Archives //////
@@ -189,6 +199,16 @@
 #define _TestBeforeUnpack	true 
 // Supported Packers // ====> a QStringList of SYSTEM supported archives ( also new )
 
+/////////////////////// [UserActions]
+// Terminal for UserActions ///////////
+#define _UserActions_Terminal      "konsole --noclose -e"
+// Normal font for output collection ///////
+#define _UserActions_NormalFont   new QFont(KGlobalSettings::generalFont())
+// Font for output collection with fixed width ///////
+#define _UserActions_FixedFont   new QFont(KGlobalSettings::fixedFont())
+// Use for output collection  fixed width font as default ///////
+#define _UserActions_UseFixedFont   false
+
 /////////////////////// [Private]
 // Start Position /////
 #define _StartPosition new QPoint(QApplication::desktop()->width()/2 - mainView->sizeHint().width()/2,QApplication::desktop()->height()/2 - 250) 
