@@ -39,7 +39,6 @@
 #include <kprocess.h>
 #include <kmessagebox.h>
 #include <klineeditdlg.h>
-#include <kkeydialog.h>
 #include <kdirnotify_stub.h>
 #include <kio/netaccess.h>
 #include <kedittoolbar.h>
@@ -58,10 +57,13 @@
 #include "krusaderview.h"
 #include "Panel/listpanel.h"
 #include "Panel/krselectionmode.h"
+#include "Panel/krdetailedview.h"
 #include "Panel/krdetailedviewitem.h"
+#include "Panel/krbriefview.h"
 #include "Panel/krbriefviewitem.h"
 #include "Dialogs/krdialogs.h"
 #include "Dialogs/krspwidgets.h"
+#include "Dialogs/krkeydialog.h"
 #include "GUI/krusaderstatus.h"
 #include "RemoteMan/remoteman.h"
 #include "Panel/panelfunc.h"
@@ -81,6 +83,7 @@
 #include "Splitter/splittergui.h"
 #include "Splitter/splitter.h"
 #include "Splitter/combiner.h"
+#include "ActionMan/actionman.h"
 #include "UserMenu/usermenu.h"
 #include "Panel/panelpopup.h"
 #include "Synchronizer/synchronizergui.h"
@@ -209,12 +212,30 @@ void KRslots::compareContent( KURL url1, KURL url2 )
 }
 
 void KRslots::rightclickMenu() {
-  ACTIVE_PANEL->popRightClickMenu(
-   ACTIVE_PANEL->mapToGlobal(
-   dynamic_cast<KListView*>(ACTIVE_PANEL->view)->itemRect(dynamic_cast<QListViewItem*>
-   (ACTIVE_PANEL->view->getCurrentKrViewItem())).topLeft()
-   )
-  );
+  if( dynamic_cast<KrDetailedView*>(ACTIVE_PANEL->view) != 0 )
+  {
+    QListViewItem * currentItem = dynamic_cast<QListViewItem*>(ACTIVE_PANEL->view->getCurrentKrViewItem());
+    if( currentItem )
+    {
+      ACTIVE_PANEL->popRightClickMenu(
+       ACTIVE_PANEL->mapToGlobal(
+         dynamic_cast<KListView*>(ACTIVE_PANEL->view)->itemRect( currentItem ).topLeft()
+       )
+      );
+    }
+  }
+  else if( dynamic_cast<KrBriefView*>(ACTIVE_PANEL->view) != 0 )
+  {
+    QIconViewItem * currentItem = dynamic_cast<QIconViewItem*>(ACTIVE_PANEL->view->getCurrentKrViewItem());
+    if( currentItem )
+    {
+      ACTIVE_PANEL->popRightClickMenu(
+       ACTIVE_PANEL->mapToGlobal(
+         currentItem->rect().topLeft()
+       )
+      );
+    }
+  }
 }
 
 void KRslots::addBookmark(){
@@ -263,14 +284,26 @@ void KRslots::insertFileName(bool full_path)
     return;
   
   if( full_path ){
-    QString path=ACTIVE_FUNC->files()->vfs_getOrigin().prettyURL(1,KURL::StripFileProtocol);
+    QString path=vfs::pathOrURL( ACTIVE_FUNC->files()->vfs_getOrigin(), 1 );
     filename = path+filename;
   }
 
-  QString current = MAIN_VIEW->cmdLine->text();
-  if( current.length() != 0 && !current.endsWith( " " ) )
-    current += " ";
-  MAIN_VIEW->cmdLine->setText( current + filename );
+  filename = KrServices::quote( filename );
+
+  if(MAIN_VIEW->cmdLine->isVisible() || !MAIN_VIEW->konsole_part || !MAIN_VIEW->konsole_part->widget() ||
+    !MAIN_VIEW->konsole_part->widget()->isVisible() ){
+    QString current = MAIN_VIEW->cmdLine->text();
+    if( current.length() != 0 && !current.endsWith( " " ) )
+      current += " ";
+    MAIN_VIEW->cmdLine->setText( current + filename );
+	MAIN_VIEW->cmdLine->setFocus();
+  }
+  else if(MAIN_VIEW->konsole_part){
+    filename = QString( " " ) + filename + QString( " " );
+    QKeyEvent keyEvent( QEvent::KeyPress, 0, -1, 0,  filename);
+    QApplication::sendEvent( MAIN_VIEW->konsole_part->widget(), &keyEvent );
+    MAIN_VIEW->konsole_part->widget()->setFocus();
+  }
 }
 
 // directory list functions
@@ -326,9 +359,20 @@ void KRslots::runKonfigurator(bool firstTime) {
     KrSelectionMode::resetSelectionHandler();
   }
   
+  krApp->configChanged();
   delete konfigurator;
 }
 
+void KRslots::setDetailedView() {
+  if( ACTIVE_PANEL && ACTIVE_PANEL->getType() != "Detailed" )
+    ACTIVE_PANEL->changeType( "Detailed" );
+}
+
+void KRslots::setBriefView() {
+  if( ACTIVE_PANEL && ACTIVE_PANEL->getType() != "Brief" )
+    ACTIVE_PANEL->changeType( "Brief" );
+}
+
 void KRslots::toggleHidden(){
   krConfig->setGroup("Look&Feel");
   bool show = !krConfig->readBoolEntry("Show Hidden",_ShowHidden);
@@ -339,7 +383,15 @@ void KRslots::toggleHidden(){
   MAIN_VIEW->rightMng->refreshAllTabs( true );
 }
 
-void KRslots::toggleSwapPanels(){
+void KRslots::swapPanels(){
+  KURL leftURL = MAIN_VIEW->left->func->files()->vfs_getOrigin();
+  KURL rightURL = MAIN_VIEW->right->func->files()->vfs_getOrigin();
+
+  MAIN_VIEW->left->func->openUrl( rightURL );
+  MAIN_VIEW->right->func->openUrl( leftURL );
+}
+
+void KRslots::toggleSwapSides(){
   QValueList<int> lst = MAIN_VIEW->horiz_splitter->sizes();
 
   MAIN_VIEW->horiz_splitter->moveToLast( MAIN_VIEW->leftMng );
@@ -392,8 +444,13 @@ void KRslots::locate()
     return;
   }
   
-  LocateDlg *loc = new LocateDlg();
-  delete loc;
+  if ( LocateDlg::LocateDialog != 0 ) {
+    LocateDlg::LocateDialog->showNormal();
+    LocateDlg::LocateDialog->raise();
+    LocateDlg::LocateDialog->setActiveWindow();
+    LocateDlg::LocateDialog->reset();
+  } else
+    LocateDlg::LocateDialog = new LocateDlg();
 }
 
 void KRslots::runRemoteMan() {
@@ -506,7 +563,7 @@ void KRslots::configToolbar(){
 }
 
 void KRslots::configKeys(){
-  KKeyDialog::configure(krApp->actionCollection(), 0, true);
+  KrKeyDialog( MAIN_VIEW );
 }
 
 // misc
@@ -581,9 +638,8 @@ void KRslots::previousTab() {
   ACTIVE_PANEL_MANAGER->slotPreviousTab();
 }
 
-void KRslots::newTab(QListViewItem *item) {
-  if (!item) return;
-  KrViewItem *it = dynamic_cast<KrViewItem*>(item);
+void KRslots::newTab(KrViewItem *it) {
+  if (!it) return;
   if( it->name() == ".." ) {
     KURL url = ACTIVE_PANEL->virtualPath();
     ACTIVE_PANEL_MANAGER->slotNewTab( url.upURL() );
@@ -615,8 +671,8 @@ void KRslots::slotSplit()
     return;
   }
 
-  QString fileName = ACTIVE_FUNC->files()->vfs_getFile(name).prettyURL(-1,KURL::StripFileProtocol);
-  if( fileName == QString::null )
+  KURL fileURL = ACTIVE_FUNC->files()->vfs_getFile(name);
+  if( fileURL.isEmpty() )
     return;
 
   if ( ACTIVE_FUNC->files()->vfs_search( name )->vfile_isDir() ) {
@@ -624,15 +680,15 @@ void KRslots::slotSplit()
     return ;
   }
 
-  QString destDir  = ACTIVE_PANEL->otherPanel->func->files()->vfs_getOrigin().prettyURL(-1,KURL::StripFileProtocol);
+  KURL destDir  = ACTIVE_PANEL->otherPanel->func->files()->vfs_getOrigin();
 
-  SplitterGUI splitterGUI( MAIN_VIEW, fileName, destDir );
+  SplitterGUI splitterGUI( MAIN_VIEW, fileURL, destDir );
 
   if( splitterGUI.result() == QDialog::Accepted )
   {
-    bool splitToOtherPanel = ( vfs::fromPathOrURL( splitterGUI.getDestinationDir() ).equals( ACTIVE_PANEL->otherPanel->virtualPath(), true ) );
+    bool splitToOtherPanel = ( splitterGUI.getDestinationDir().equals( ACTIVE_PANEL->otherPanel->virtualPath(), true ) );
 
-    Splitter split( MAIN_VIEW, fileName, splitterGUI.getDestinationDir() );
+    Splitter split( MAIN_VIEW, fileURL, splitterGUI.getDestinationDir() );
     split.split( splitterGUI.getSplitSize() );
 
     if ( splitToOtherPanel )
@@ -682,7 +738,7 @@ void KRslots::slotCombine(){
       {
         if( windowsStyle )
         {
-          KMessageBox::error(0,i18n("Not a split file %1!").arg( url.prettyURL(0, KURL::StripFileProtocol ) ));
+          KMessageBox::error(0,i18n("Not a split file %1!").arg( vfs::pathOrURL( url ) ));
           return;
         }
         unixStyle = true;
@@ -745,14 +801,14 @@ void KRslots::slotCombine(){
 
       if( error )
       {
-        KMessageBox::error(0,i18n("Not a splitted file %1!").arg( url.prettyURL(0, KURL::StripFileProtocol ) ));
+        KMessageBox::error(0,i18n("Not a splitted file %1!").arg( vfs::pathOrURL( url ) ));
         return;
       }
     }
   }
 
    // ask the user for the copy dest
-  KURL dest = KChooseDir::getDir(i18n("Combining %1.* to directory:" ).arg( baseURL.prettyURL( 0, KURL::StripFileProtocol ) ),
+  KURL dest = KChooseDir::getDir(i18n("Combining %1.* to directory:" ).arg( vfs::pathOrURL( baseURL ) ),
                                  ACTIVE_PANEL->otherPanel->virtualPath(), ACTIVE_PANEL->virtualPath());
   if ( dest.isEmpty() ) return ; // the user canceled
 
@@ -772,26 +828,19 @@ void KRslots::userMenu() {
 }
 
 void KRslots::manageUseractions() {
-   Konfigurator konfigurator( false, 7 ); // page 7 are the UserActions
+   ActionMan actionMan( MAIN_VIEW );
 }
 
 void KRslots::slotSynchronizeDirs( QStringList selected ) {
-  SynchronizerGUI *sync = new SynchronizerGUI( krApp,
-                MAIN_VIEW->left->func->files()->vfs_getOrigin().prettyURL(0,KURL::StripFileProtocol),
-                MAIN_VIEW->right->func->files()->vfs_getOrigin().prettyURL(0,KURL::StripFileProtocol), selected );
-
-  bool refresh = sync->wasSynchronization();
-  delete sync;
-
-  if( refresh )
-    REFRESH_BOTH_PANELS;
+  new SynchronizerGUI( 0, MAIN_VIEW->left->func->files()->vfs_getOrigin(),
+                          MAIN_VIEW->right->func->files()->vfs_getOrigin(), selected );
 }
 
 void KRslots::slotSyncBrowse() {
    ACTIVE_PANEL->syncBrowseButton->toggle();
 }
 
-void KRslots::updatePopupPanel(QListViewItem *it) {
+void KRslots::updatePopupPanel(KrViewItem *item) {
 	// which panel to display on?
 	ListPanel *lp = 0;
 	if (ACTIVE_PANEL->popup->isHidden() &&
@@ -801,7 +850,6 @@ void KRslots::updatePopupPanel(QListViewItem *it) {
 	else if (ACTIVE_PANEL->otherPanel->popup->isShown())
 		lp = ACTIVE_PANEL->otherPanel;
 
-	KrViewItem *item = dynamic_cast<KrViewItem*>(it);
 	KURL url;
 	if (item->name()!="..") // updir
 		url = ACTIVE_FUNC->files()->vfs_getFile(item->name());
@@ -825,13 +873,29 @@ void KRslots::compareSetup()
     }
 }
 
+/** called by actions actExec* to choose the built-in command line mode  */
+void KRslots::execTypeSetup()
+{
+  for( int i=0; Krusader::execTypeArray[i] != 0; i++ )
+    if( (*Krusader::execTypeArray[i])->isChecked() )
+    {
+      if( *Krusader::execTypeArray[i] == Krusader::actExecTerminalEmbedded ){
+         // if commands are to be executed in the TE, it must be loaded
+         MAIN_VIEW->createTE();
+      }
+      KConfigGroup grp(krConfig,  "Private" );
+      grp.writeEntry( "Command Execution Mode", i );
+      break;
+    }
+}
+
 void KRslots::togglePopupPanel() {
 	ACTIVE_PANEL->togglePanelPopup();
 }
 
 void KRslots::slotDiskUsage()
 {
-  DiskUsageGUI du( ACTIVE_FUNC->files()->vfs_getOrigin().prettyURL(1,KURL::StripFileProtocol), MAIN_VIEW, "DiskUsage" );
+  DiskUsageGUI du( ACTIVE_FUNC->files()->vfs_getOrigin(), MAIN_VIEW, "DiskUsage" );
 }
 
 // when window becomes focused, enable the refresh in the visible panels
