@@ -42,6 +42,7 @@
 #include "BookMan/krbookmarkbutton.h"
 #include "GUI/kcmdline.h"
 #include "GUI/dirhistorybutton.h"
+#include "GUI/mediabutton.h"
 
 class ListPanel;
 class KURL;
@@ -64,8 +65,11 @@ class KRslots : public QObject {
     void rightclickMenu();
     void insertFileName(bool full_path);
     void rootKrusader();
+    void swapPanels();
+    void setBriefView();
+    void setDetailedView();
     void toggleHidden();
-    void toggleSwapPanels();
+    void toggleSwapSides();
 	 void togglePopupPanel();
     void configToolbar();
     void configKeys();
@@ -84,6 +88,8 @@ class KRslots : public QObject {
     void invert();
     void compareDirs();
     void compareSetup();
+    /** called by actExec* actions to choose the built-in command line mode */
+    void execTypeSetup();
     void refresh();
     void refresh( const KURL& u );
     void properties();
@@ -120,6 +126,9 @@ class KRslots : public QObject {
 	 void openHistory() { ACTIVE_PANEL->historyButton->openPopup(); }
     void openLeftHistory() { LEFT_PANEL->historyButton->openPopup(); }
     void openRightHistory() { RIGHT_PANEL->historyButton->openPopup(); }
+    void openMedia() { ACTIVE_PANEL->mediaButton->openPopup(); }
+    void openLeftMedia() { LEFT_PANEL->mediaButton->openPopup(); }
+    void openRightMedia() { RIGHT_PANEL->mediaButton->openPopup(); }
 	 void syncPanels() {
 	 	ListPanel *t = ACTIVE_PANEL;
 		OTHER_FUNC->openUrl(ACTIVE_PANEL->virtualPath());
@@ -128,7 +137,7 @@ class KRslots : public QObject {
     void cmdlinePopup() { MAIN_VIEW->cmdLine->popup(); }
     void duplicateTab();
     void newTab(const KURL& url = KURL());
-    void newTab(QListViewItem *item);
+    void newTab(KrViewItem *item);
     void closeTab();
     void nextTab();
     void previousTab();
@@ -143,7 +152,7 @@ class KRslots : public QObject {
     void slotJumpBack();
     void slotSetJumpBack();
     void newSymlink() { ACTIVE_PANEL->func->krlink(true); }
-    void updatePopupPanel(QListViewItem*);
+    void updatePopupPanel(KrViewItem *);
 		void windowActive(); // called when krusader's window becomes focussed
 		void windowInactive(); // called when another application steals the focus
     // F2
