@@ -22,12 +22,12 @@ class PanelManager: public QWidget {
      * (self, other, active), which enables it to manage pointers held by the panels transparently.
      * It also receives a bool (left) which is true if the manager is the left one, or false otherwise.
      */
-    PanelManager( QWidget *parent, bool left, ListPanel* &self, ListPanel* &other, ListPanel* &active);
+    PanelManager( QWidget *parent, bool left );
     /**
      * Called once by KrusaderView to create the first panel. Subsequent called are done internally
      * Note: only creates the panel, but doesn't start the VFS inside it. Use startPanel() for that.
      */
-    ListPanel* createPanel( bool setCurrent = true );
+    ListPanel* createPanel( QString type, bool setCurrent = true );
     /**
      * Called once by KrusaderView to start the first panel. Subsequent called are done internally
      * Only starts the VFS inside the panel, you must first use createPanel() !
@@ -36,7 +36,7 @@ class PanelManager: public QWidget {
     /**
      * Swaps the left / right directions of the panel
      */
-    void swapPanels()             {_left = !_left;}
+    void swapPanels();
     
     void saveSettings(KConfig *config, const QString& key, bool localOnly = true );
     void loadSettings(KConfig *config, const QString& key);
@@ -50,7 +50,7 @@ class PanelManager: public QWidget {
      * Called externally to start a new tab. Example of usage would be the "open in a new tab"
      * action, from the context-menu.
      */
-    void slotNewTab(const KURL& url, bool setCurrent = true );
+    void slotNewTab(const KURL& url, bool setCurrent = true, QString type = QString::null, int props = 0 );
     void slotNewTab();
     void slotNextTab();
     void slotPreviousTab();	 
@@ -71,7 +71,7 @@ class PanelManager: public QWidget {
     PanelTabBar *_tabbar;
     QWidgetStack *_stack;
     QToolButton *_newTab, *_closeTab;
-    ListPanel *&_self, *&_other, *&_active;
+    ListPanel **_selfPtr, **_otherPtr;
 };
 
 
