@@ -29,6 +29,8 @@
 #include <qtooltip.h>
 #include <kdebug.h>
 
+#define DISPLAY(X)	(X.isLocalFile() ? X.path() : X.prettyURL())
+
 PanelTabBar::PanelTabBar(QWidget *parent): QTabBar(parent), _maxTabLength(0) {
   _panelActionMenu = new KActionMenu( i18n("Panel"), this );
 
@@ -74,11 +76,11 @@ void PanelTabBar::insertAction( KAction* action ) {
 }
 
 int PanelTabBar::addPanel(ListPanel *panel, bool setCurrent ) {
-  int newId = addTab(new PanelTab(squeeze(panel->virtualPath), panel));
+  int newId = addTab(new PanelTab(squeeze(DISPLAY(panel->virtualPath())), panel));
 
   // make sure all tabs lengths are correct
   for (int i=0; i<count(); i++)
-    tabAt(i)->setText(squeeze(dynamic_cast<PanelTab*>(tabAt(i))->panel->virtualPath, i));
+    tabAt(i)->setText(squeeze(DISPLAY(dynamic_cast<PanelTab*>(tabAt(i))->panel->virtualPath()), i));
   layoutTabs();
   
   if( setCurrent )
@@ -102,7 +104,7 @@ ListPanel* PanelTabBar::removeCurrentPanel(ListPanel* &panelToDelete) {
   removeTab(tab(id));
 
   for (int i=0; i<count(); i++)
-    tabAt(i)->setText(squeeze(dynamic_cast<PanelTab*>(tabAt(i))->panel->virtualPath, i));
+    tabAt(i)->setText(squeeze(DISPLAY(dynamic_cast<PanelTab*>(tabAt(i))->panel->virtualPath()), i));
   layoutTabs();
 
   // setup current one
@@ -121,7 +123,7 @@ void PanelTabBar::updateTab(ListPanel *panel) {
   // find which is the correct tab
   for (int i=0; i<count(); i++) {
     if (dynamic_cast<PanelTab*>(tabAt(i))->panel == panel) {
-      tabAt(i)->setText(squeeze(panel->virtualPath,i));
+      tabAt(i)->setText(squeeze(DISPLAY(panel->virtualPath()),i));
       break;
     }
   }
@@ -129,7 +131,7 @@ void PanelTabBar::updateTab(ListPanel *panel) {
 
 void PanelTabBar::duplicateTab() {
   int id = currentTab();
-  emit newTab(dynamic_cast<PanelTab*>(tab(id))->panel->virtualPath);
+  emit newTab(dynamic_cast<PanelTab*>(tab(id))->panel->virtualPath());
 }
 
 void PanelTabBar::closeTab() {
@@ -226,12 +228,11 @@ QString PanelTabBar::squeeze(QString text, int index) {
 }
 
 void PanelTabBar::resizeEvent ( QResizeEvent *e ) {
-   QTabBar::resizeEvent( e );
-   qApp->processEvents();
+    QTabBar::resizeEvent( e );
      
-   for (int i=0; i<count(); i++)
-     tabAt(i)->setText(squeeze(dynamic_cast<PanelTab*>(tabAt(i))->panel->virtualPath, i));
-   layoutTabs();
+    for (int i=0; i<count(); i++)
+      tabAt(i)->setText(squeeze(DISPLAY(dynamic_cast<PanelTab*>(tabAt(i))->panel->virtualPath()), i));
+    layoutTabs();
 }
 
 
